@@ -20,6 +20,9 @@
 #define SETUP_SCREEN_DIM_PERCENT "screen/dim_percent"
 #define SETUP_SCREEN_DIM_PERCENT_DEFAULT 20
 
+#define SETUP_FULLSCREEN_STARTUP "screen/fullscreen_startup"
+#define SETUP_FULLSCREEN_STARTUP_DEFAULT false
+
 #define SETUP_NOTIFICATION_TIMEOUT "notification/timeout"
 #define SETUP_NOTIFICATION_TIMEOUT_DEFAULT 3
 
