@@ -6,6 +6,10 @@ LegendDialog::LegendDialog(QWidget *parent) :
     ui(new Ui::LegendDialog)
 {
     ui->setupUi(this);
+
+#if defined(Q_WS_MAEMO_5)
+    setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
+#endif
 }
 
 LegendDialog::~LegendDialog()
