@@ -2,6 +2,7 @@
 #define SETUPDIALOG_H
 
 #include <QDialog>
+#include <QDialogButtonBox>
 
 namespace Ui {
     class SetupDialog;
@@ -19,14 +20,13 @@ public:
 
 private slots:
     void on_screenDimTimeoutSlider_valueChanged(int value);
-
     void on_screenDimPercentSlider_valueChanged(int value);
-
     void on_screenLockTimeoutSlider_valueChanged(int value);
-
     void on_notificationTimeoutSlider_valueChanged(int value);
+    void on_buttonBox_clicked(QAbstractButton* button);
 
 private:
+    void load(bool restore_defaults);
     Ui::SetupDialog *ui;
 };
 
