@@ -1,16 +1,19 @@
 #include "timedstate.h"
 
+#define INTERNAL_TIMER_TICK 1000 // tick every 1 sec
+
 TimedState::TimedState(const QString& name, int timeout, QState *parent)
-    : QState(parent), m_name(name), m_timeout(timeout)
+    : NamedState(name, parent), m_timeout(timeout)
 {
 }
 
-void TimedState::onEntry(QEvent */*event*/)
+void TimedState::onEntry(QEvent *event)
 {
-    qDebug("TimedState[%s]::onEntry", qPrintable(m_name));
     if (!m_timer.isActive())
-        m_timer.start(1000, this);
+        m_timer.start(INTERNAL_TIMER_TICK, this);
     m_elapsedTimer.restart();
+
+    NamedState::onEntry(event);
 }
 
 void TimedState::onExit(QEvent* /*event*/)
@@ -21,7 +24,7 @@ void TimedState::onExit(QEvent* /*event*/)
 void TimedState::timerEvent(QTimerEvent *)
 {
     if (m_elapsedTimer.hasExpired(m_timeout))
-        emit finished();
+        emit timeout();
 }
 
 void TimedState::setTimeout(int timeout)
